@@ -1,3 +1,4 @@
+
 --
 -- ### Cast checks
 -- 
@@ -7,9 +8,9 @@
 drop if exists table t_castcheck;
 
 
-create table t_castcheck ( a int, b fixed(2), c decimal(2), d string(10));
+create table t_castcheck ( a int, b decimal(10,2), c string(10));
 
-insert into t_castcheck values ( 20, (fixed)22.23, (decimal)44.99, '3.45' );
+insert into t_castcheck values ( 20, (decimal)44.99, '3.45' );
 
 select * from t_castcheck;
 
@@ -25,9 +26,9 @@ select c - b from t_castcheck;
 select c * b from t_castcheck;
 select b * c from t_castcheck;
 
-select b + d from t_castcheck;
-select d + b from t_castcheck;
-select b * d from t_castcheck;
+select b + c from t_castcheck;
+select c + b from t_castcheck;
+select b * c from t_castcheck;
 -- select d * b from t_castcheck; not working, target datatype must be specified as first operand
 
 
