@@ -60,6 +60,7 @@ CegoAdmAction::CegoAdmAction(CegoAdminHandler *pAH, CegoModule *pModule, CegoAdm
     _pModule = pModule;
     _pAH = pAH;
     _pit = Chain();
+    _lsn = 0;
     _rawMode = rawMode;
     _resultMode = resultMode;
     _keepTicket = false;
@@ -1569,11 +1570,12 @@ void CegoAdmAction::recoverTableSetAction()
 	tableSet = *pS;
     }
     CegoAdminHandler::ResultType res;
-    res = _pAH->medRecover(tableSet, _pit);
+    res = _pAH->medRecover(tableSet, _pit, _lsn);
     handleMedResult(res);
 
     // reset pit to 0
     _pit = Chain();
+    _lsn = 0;
 
     Chain msg;
     _pAH->getMsg(msg);
@@ -3430,6 +3432,16 @@ void CegoAdmAction::storePit()
     _pit = Chain(_stringBuf);
 }
 
+void CegoAdmAction::storeLsn()
+{
+    Chain* pS = getTokenList().First();
+    if ( pS )
+    {
+	_lsn = pS->asUnsignedLongLong();
+    }
+}
+
+
 void CegoAdmAction::dumpTable()
 {
     Chain tableSet;
