@@ -79,7 +79,7 @@ class CegoAdmNet {
     void relocateSecondary(const Chain& tableSet, const Chain& secondary);
     void relocateMediator(const Chain& tableSet, const Chain& mediator);
 
-    void recoverTableSet(const Chain& tableSet, const Chain& pit);
+    void recoverTableSet(const Chain& tableSet, const Chain& pit, unsigned long long targetlsn);
 
     void disconnect();
 
