@@ -1774,8 +1774,9 @@ Screen::Panel* CegoAdmScreen::TableSet::Action::Backup::Restore::onConfirm(const
 	_pAH->getMsg(msg);	
 	return setError(Chain(ERROR_TITLE), msg);
     }
-    
-    res = _pAH->medRecover(_tableSet, pit);
+
+    // far now, we do not support lsn recovery
+    res = _pAH->medRecover(_tableSet, pit, 0);
         
     while ( res == CegoAdminHandler::ADM_INFO )
     {
