@@ -111,13 +111,8 @@ int main(int argc, char **argv)
     Chain user;
     Chain password;
     
-#ifdef HAVE_MINGW
-    Chain homeDir(getenv("HOMEPATH"));
-    Chain histPath = homeDir + "\\" + Chain(HISTFILE);
-#else
     Chain homeDir(getenv("HOME"));
     Chain histPath = homeDir + "/" + Chain(HISTFILE);
-#endif
 
     // default run mode is interactive
     RunMode runMode = INTERACTIVE;
@@ -163,7 +158,13 @@ int main(int argc, char **argv)
     CegoAdminHandler* pAH = 0;
     NetHandler* pN = 0;
     unsigned long modId = 0;
+    CegoAdmAction* pAdm = 0;
 
+    Chain command;    
+    File *pInput = 0;
+
+    int exitCode = 0;
+    
     try
     {
 	Chain authString = longOpt.getOptValue("user");
@@ -201,51 +202,43 @@ int main(int argc, char **argv)
 	    pAH->getMsg(msg);
 	    throw Exception(EXLOC, msg);
 	}
-    }
-    catch ( Exception e)
-    {
-	Chain msg;
-	e.pop(msg);
-	cerr << msg << endl;
-	exit(1);
-    }
 
-    Chain command;
-    
-    File *pInput = 0;
-
-    if ( longOpt.isSet("batchfile") )
-    {
-	runMode = BATCH;
-	Chain batchFileName = longOpt.getOptValue("batchfile");
-	pInput = new File(batchFileName);
-	pInput->open(File::READ);
-    }
-    else if ( longOpt.isSet("cmd") )
-    {
-	runMode = COMMAND;
-	command = longOpt.getOptValue("cmd");
-    }
-    else if ( longOpt.isSet("screen") )
-    {
-	runMode = SC;
-    }
-    else
-    {
-	// if data available from stdin, we also setup batch mode
-	pInput = new File(File::IN);
-	if ( pInput->hasData(PIPE_TIMEOUT) )
+	if ( longOpt.isSet("batchfile") )
 	{
-	    runMode = BATCH;	
+	    runMode = BATCH;
+	    Chain batchFileName = longOpt.getOptValue("batchfile");
+	    pInput = new File(batchFileName);
+	    
+	    if ( pInput->exists() == false )
+	    {
+		delete pInput;
+		pInput=0;
+		Chain msg = Chain("File ") + batchFileName + Chain(" does not exist");
+		throw Exception(EXLOC, msg);
+	    }
+	    pInput->open(File::READ);
 	}
-    }
-    
-    CegoAdmAction* pAdm = new CegoAdmAction(pAH, pModule, resultMode, rawMode);
-
-    int exitCode = 0;
-
-    try
-    {
+	else if ( longOpt.isSet("cmd") )
+	{
+	    runMode = COMMAND;
+	    command = longOpt.getOptValue("cmd");
+	}
+	else if ( longOpt.isSet("screen") )
+	{
+	    runMode = SC;
+	}
+	else
+	{
+	    // if data available from stdin, we also setup batch mode
+	    pInput = new File(File::IN);
+	    if ( pInput->hasData(PIPE_TIMEOUT) )
+	    {
+		runMode = BATCH;	
+	    }
+	}
+	
+	pAdm = new CegoAdmAction(pAH, pModule, resultMode, rawMode);
+	
 	switch ( runMode )
 	{
 	case SC:
@@ -416,13 +409,25 @@ int main(int argc, char **argv)
 	Chain msg;
 	e.pop(msg);
 	cerr << "ERROR : " << msg << endl;
+	if ( pAdm ) 
+	    delete pAdm;
+	if ( pAH )
+	    delete pAH;
+	if ( pN )
+	    delete pN;
+	if ( pModule )
+	    delete pModule;	
 	exit(1);
     }
-    
-    delete pAdm;
-    delete pAH;
-    delete pN;
-    delete pModule;
+
+    if ( pAdm ) 
+	delete pAdm;
+    if ( pAH )
+	delete pAH;
+    if ( pN )
+	delete pN;
+    if ( pModule )
+	delete pModule;
 
     exit(exitCode);
 }
@@ -590,7 +595,7 @@ void helpOverview()
     cout << "   [b12] end backup for <tableset> [ message 'system message' ] [ keep ticket ]" << endl;
     cout << "   [b13] list backup for <tableset> [ to '<point in time>' ]" << endl;
     cout << "   [b14] restore tableset <tableset> from '<backupId>'" << endl;
-    cout << "   [b15] recover tableset <tableset> [ to '<point in time>' ]" << endl;
+    cout << "   [b15] recover tableset <tableset> [ to ( pit '<point in time>' | lsn <lsn> ) ]" << endl;
     cout << "   [b16] export [ xml | binary | plain ]  table <table> from <tableset> to '<filename>'" << endl;
     cout << "   [b17] export [ xml | binary | plain ] tableset [ structure ] <tableset> to '<filename>'" << endl;
     cout << "   [b18] import [ xml | binary | plain ] table <table> to <tableset> from '<filename>'" << endl;
@@ -1566,8 +1571,8 @@ void helpTopic(const Chain& topic)
     else if ( topic == Chain("b15"))
     {
 	cout << endl;
-	cout << "recover tableset <tableset> [ to <point in time>]" << endl;
-	cout << "-------------------------------------------------------------" << endl;
+	cout << "recover tableset <tableset> [ to ( pit <timestamp> | lsn <lsn> ) ]" << endl;
+	cout << "----------------------------------------------------------------------" << endl;
 	cout << endl;
 	cout << "   Execute an up-to-crash or point in time recover for the given tableset." << endl;
 	cout << "   The corresponding tableset must be in status offline perform this action." << endl;
@@ -1575,10 +1580,14 @@ void helpTopic(const Chain& topic)
 	cout << "   If an online backup should be restored, a valid backup ticket file has to be provided." << endl;
 	cout << "   This can be done in a convenient way by using the 'restore tableset' command." << endl;
 	cout << endl;
-	cout << "   If point-in-time is used, an appropriate time stamp has to be provided with the server supported date format." << endl;
-	cout << "   The default format value is <dd.mm.YYYY HH:MM:SS>" << endl;
+	cout << "   If point-in-time is used, an appropriate time stamp or log sequence number ( LSN ) has to be provided." << endl;
+	cout << "   The timestamp must be given in the configured supported date format." << endl;
+	cout << "   Default timestamp format is <dd.mm.YYYY HH:MM:SS>" << endl;
+	cout << "   LSN must be given as a numeric value" << endl;
 	cout << endl;
-	cout << "   Sample : recover tableset TS1 to '09.07.2016 08:12:34';" << endl;
+	cout << "   Samples :"<< endl;
+	cout << "      recover tableset TS1 to pit '09.07.2016 08:12:34';" << endl;
+	cout << "      recover tableset TS1 to lsn 53366;" << endl;	
 	cout << endl;
 	cout << "   After the recovery has been finished succesful, the corresponding tableset is online." << endl;
 	cout << endl;
