@@ -6,7 +6,7 @@
 //      
 // Design and Implementation by Bjoern Lemke
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // IMPLEMENTATION MODULE
 //
@@ -31,11 +31,6 @@ CegoAlterDesc::CegoAlterDesc()
 {
 }
 
-CegoAlterDesc::CegoAlterDesc(Element *pAlterElement)
-{
-    fromElement(pAlterElement);
-}
-
 CegoAlterDesc::CegoAlterDesc(CegoAlterDesc::AlterType type, const CegoField& f)
 {
     _f = f;
@@ -53,7 +48,6 @@ CegoAlterDesc::CegoAlterDesc(const Chain& attrName)
     _f.setAttrName(attrName);
 }
 
-
 CegoAlterDesc::CegoAlterDesc(const Chain& attrName, const CegoFieldValue& defaultValue)
 {
     _type = MODIFY_DEFAULT;
@@ -61,7 +55,6 @@ CegoAlterDesc::CegoAlterDesc(const Chain& attrName, const CegoFieldValue& defaul
     _f.setAttrName(attrName);    
 }
 
-
 CegoAlterDesc::CegoAlterDesc(const Chain& oldAttrName, const Chain& newAttrName)
 {
     _type = RENAME;
@@ -160,78 +153,6 @@ Chain CegoAlterDesc::dbFormat(CegoDatabaseFormater *pForm) const
     return pForm->formatAlter(_type, _f, _attrName);    
 }
 
-Element* CegoAlterDesc::toElement() const
-{
-    Element* pAlterElement = new Element(XML_ALTER_ELEMENT);
-
-    switch ( _type )
-    {
-    case CegoAlterDesc::ADD:
-    {
-	pAlterElement->setAttribute( XML_TYPE_ATTR, XML_ADD_VALUE ); 
-	break;
-    }
-    case CegoAlterDesc::DROP:
-    {
-	pAlterElement->setAttribute( XML_TYPE_ATTR, XML_DROP_VALUE ); 
-	break;
-    }
-    case CegoAlterDesc::MODIFY_COLUMN:
-    {
-	pAlterElement->setAttribute( XML_TYPE_ATTR, XML_MODIFY_COLUMN_VALUE ); 
-	break;
-    }
-    case CegoAlterDesc::MODIFY_DEFAULT:
-    {
-	pAlterElement->setAttribute( XML_TYPE_ATTR, XML_MODIFY_DEFAULT_VALUE ); 
-	break;
-    }
-    case CegoAlterDesc::RENAME:
-    {
-	pAlterElement->setAttribute( XML_TYPE_ATTR, XML_RENAME_VALUE ); 
-	break;
-    }
-    }
-    pAlterElement->setAttribute( XML_ATTRNAME_ATTR, _attrName ); 
-    pAlterElement->addContent( _f.toElement() );
-    
-    return pAlterElement;   
-}
-
-void CegoAlterDesc::fromElement(Element *pAlterElement)
-{
-    Chain alterTypeString = pAlterElement->getAttributeValue( XML_TYPE_ATTR );
-    
-    if ( alterTypeString == Chain(XML_ADD_VALUE) )
-    {
-	_type = CegoAlterDesc::ADD;
-    }
-    else if ( alterTypeString == Chain(XML_MODIFY_COLUMN_VALUE) )
-    {
-	_type = CegoAlterDesc::MODIFY_COLUMN;
-    }
-    else if ( alterTypeString == Chain(XML_MODIFY_DEFAULT_VALUE) )
-    {
-	_type = CegoAlterDesc::MODIFY_DEFAULT;
-    }
-    else if ( alterTypeString == Chain(XML_DROP_VALUE) )
-    {
-	_type = CegoAlterDesc::DROP;
-    }
-    else if ( alterTypeString == Chain(XML_RENAME_VALUE) )
-    {
-	_type = CegoAlterDesc::RENAME;
-    }
-    
-    ListT<Element*> fl = pAlterElement->getChildren(XML_FIELD_ELEMENT);
-    Element **pFE = fl.First();
-    if ( pFE )
-    {
-	_f.fromElement(*pFE);
-    }
-    _attrName = pAlterElement->getAttributeValue( XML_ATTRNAME_ATTR);
-}
-
 ostream& operator << (ostream& s, const CegoAlterDesc& a)
 {
     s <<  a.toChain();
