@@ -552,7 +552,7 @@ unsigned long long CegoBufferPool::writeCheckPoint(const Chain& tableSet, bool s
 {
     unsigned tabSetId = getTabSetId(tableSet);    
 
-    log(_modId, Logger::NOTICE, Chain("Writing checkpoint for tableset ") + tableSet + Chain(" as lsn = ") 
+    log(_modId, Logger::NOTICE, Chain("Writing checkpoint for tableset ") + tableSet + Chain(" at lsn = ") 
 	+ Chain(getCurrentLSN(tabSetId)) + Chain(" ..."));    
     
     unsigned long long lsn = writeCheckPoint(tabSetId, switchLog, escCmd, escTimeout, pLockHandle);
@@ -658,9 +658,9 @@ unsigned long long CegoBufferPool::writeCheckPoint(unsigned tabSetId, bool switc
 	    if ( switchLog )
 	    {      	    
 		// set commited lsn to current lsn to sync with switchLogFile if log is active
-		lsn = getCurrentLSN(tabSetId); 	    
+		lsn = getCurrentLSN(tabSetId);  
 		setCommittedLSN(tabSetId, lsn);
-		
+
 		while ( switchLogFile(tabSetId) == false )
 		{		
 		    log(_modId, Logger::NOTICE, Chain("Logfile for tabSetId ") + Chain(tabSetId) + Chain(" still active, switch failed"));		
@@ -692,7 +692,7 @@ unsigned long long CegoBufferPool::writeCheckPoint(unsigned tabSetId, bool switc
 		// set lsn before logfile switch, the method switchLogFile synchronizes with doc2Xml 
 		lsn = getCurrentLSN(tabSetId); 	    
 		setCommittedLSN(tabSetId, lsn);
-		
+
 		while ( switchLogFile(tabSetId) == false )
 		{		
 		    log(_modId, Logger::NOTICE, Chain("Logfile for tabSetId ") + Chain(tabSetId) + Chain(" still active, switch failed"));		
@@ -735,8 +735,11 @@ unsigned long long CegoBufferPool::writeCheckPoint(unsigned tabSetId, bool switc
 			    if ( needPageBackup(bh.pageId) )
 			    {
 #ifdef DEBUG
-				log(_modId, Logger::DEBUG, Chain("Reading page (") + Chain(bh.fileId) + Chain(",") + Chain(bh.pageId) + Chain(") to log ..."));
-#endif	
+				log(_modId, Logger::DEBUG, Chain("Reading page ") + Chain(bh.pageId) + Chain(" to log "));
+#endif
+				
+				log(_modId, Logger::NOTICE, Chain("Saving page ") + Chain(bh.pageId) + Chain(" to log"));
+				
 				unsigned ts;
 				unsigned fixStat;
 				char *pageData = new char[_pageSize];
@@ -768,7 +771,12 @@ unsigned long long CegoBufferPool::writeCheckPoint(unsigned tabSetId, bool switc
 				    }	    		
 				}
 				delete[] pageData;
-			    }		 
+			    }
+			    else
+			    {
+				log(_modId, Logger::NOTICE, Chain("Skipping save for page ") + Chain(bh.pageId));
+			    }
+				
 			}
 			_numDiskWrite++;
 			_diskWriteTimer.start();
@@ -875,9 +883,13 @@ void CegoBufferPool::commitCheckpoint(unsigned tabSetId, CegoLockHandler *pLockH
 	{
 	    if ( needPageBackup(pageId) )
 	    {
-#ifdef DEBUG
-		log(_modId, Logger::DEBUG, Chain("Reading page (") + Chain(bh.fileId) + Chain(",") + Chain(bh.pageId) + Chain(") to log ..."));
-#endif	
+#ifdef CGDEBUG
+		log(_modId, Logger::DEBUG, Chain("Saving page ") + Chain(bh.pageId) + Chain(" to log"));		
+#endif
+
+		log(_modId, Logger::NOTICE, Chain("Saving page ") + Chain(pageId) + Chain(" to log"));
+
+				
 		unsigned ts;
 		unsigned oldFixStat;
 		char *oldPageData = new char[_pageSize];
@@ -903,7 +915,11 @@ void CegoBufferPool::commitCheckpoint(unsigned tabSetId, CegoLockHandler *pLockH
 		    throw Exception(EXLOC, Chain("Cannot perform page backup"), e);
 		}
 		delete[] oldPageData;
-	    }		 
+	    }
+	    else
+	    {
+		log(_modId, Logger::NOTICE, Chain("Skipping save for page ") + Chain(pageId));
+	    }
 	}
 	_numDiskWrite++;
 	_diskWriteTimer.start();
