@@ -47,20 +47,20 @@ public:
     void attachPool();
     void detachPool();
     
-    void bufferFix(CegoBufferPage &bp, int tabSetId, PageIdType pageId, FixMode m, CegoLockHandler *pLockHandle, int numTry = 0);
-    void emptyFix(CegoBufferPage &bp, int tabSetId, FixMode m, CegoFileHandler::FileType ft, CegoLockHandler *pLockHandle, bool doAppend = false);
+    void bufferFix(CegoBufferPage &bp, unsigned tabSetId, PageIdType pageId, FixMode m, CegoLockHandler *pLockHandle, unsigned numTry = 0);
+    void emptyFix(CegoBufferPage &bp, unsigned tabSetId, FixMode m, CegoFileHandler::FileType ft, CegoLockHandler *pLockHandle, bool doAppend = false);
 
     void bufferUnfix(CegoBufferPage &bp, bool isDirty, CegoLockHandler *pLockHandle);
     void bufferRelease(CegoBufferPage &bp, CegoLockHandler *pLockHandle);
 
-    unsigned long long writeCheckPoint(const Chain& tableSet, bool switchLog,  bool archComplete, CegoLockHandler *pLockHandle, const Chain& escCmd = Chain(), int escTimeout = ESCCMDTIMEOUT, int archTimeout = LOGARCHTIMEOUT);
-    unsigned long long writeCheckPoint(int tabSetId, bool switchLog, const Chain& escCmd, int timeout, CegoLockHandler *pLockHandle);
-    void writeAndRemoveTabSet(int tabSetId, CegoLockHandler *pLockHandle);
+    unsigned long long writeCheckPoint(const Chain& tableSet, bool switchLog,  bool archComplete, CegoLockHandler *pLockHandle, const Chain& escCmd = Chain(), unsigned escTimeout = ESCCMDTIMEOUT, unsigned archTimeout = LOGARCHTIMEOUT);
+    unsigned long long writeCheckPoint(unsigned tabSetId, bool switchLog, const Chain& escCmd, unsigned timeout, CegoLockHandler *pLockHandle);
+    void writeAndRemoveTabSet(unsigned tabSetId, CegoLockHandler *pLockHandle);
 
     unsigned long long getCPCount() const;
     
     unsigned long long uptime() const;
-    void poolInfo(int& pageSize,
+    void poolInfo(unsigned& pageSize,
 		  unsigned long long& numTotal,
 		  unsigned long long& numUsed,
 		  unsigned long long& numFree,
@@ -84,35 +84,35 @@ public:
 
     void resetStats();
 
-    void logIt(int tabSetId, CegoLogRecord& lr, CegoLockHandler* pLockHandle, bool flushLog = true);
+    void logIt(unsigned tabSetId, CegoLogRecord& lr, CegoLockHandler* pLockHandle, bool flushLog = true);
 	
     void printPool();
 
-    void getLMLockStat(int tabSetId, Chain& lockName, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
+    void getLMLockStat(unsigned tabSetId, Chain& lockName, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
 
-    void getAggLMLockStat(Chain& lockGroup, int& numLock, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
+    void getAggLMLockStat(Chain& lockGroup, unsigned& numLock, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
     
-    void restoreCheckpointDump(int tabSetId, CegoLockHandler *pLockHandle);
+    void restoreCheckpointDump(unsigned tabSetId, CegoLockHandler *pLockHandle);
 	
     Chain getDBName();
 
-    void lockPool(int tabSetId, bool doWrite);
-    void unlockPool(int tabSetId);
+    void lockPool(unsigned tabSetId, bool doWrite);
+    void unlockPool(unsigned tabSetId);
     
 private:
 
-    int calcHash(PageIdType pageId);
-    int calcSegment(PageIdType pageId);
-    void logBM(int tabSetId, int fileId, unsigned* fbm, int fbmSize, CegoLockHandler* pLockHandle);	
+    unsigned calcHash(PageIdType pageId);
+    unsigned calcSegment(PageIdType pageId);
+    void logBM(unsigned tabSetId, unsigned fileId, unsigned* fbm, unsigned fbmSize, CegoLockHandler* pLockHandle);	
     bool archiveComplete(const Chain& tableSet);
-    void optimizePool(int tabSetId);
+    void optimizePool(unsigned tabSetId);
 
     // dump methods
-    void dumpCheckpoint(int tabSetId);
-    void commitCheckpoint(int tabSetId, CegoLockHandler *pLockHandle);
+    void dumpCheckpoint(unsigned tabSetId);
+    void commitCheckpoint(unsigned tabSetId, CegoLockHandler *pLockHandle);
     
     typedef struct BufferPoolHead {
-	int numPages;
+	unsigned numPages;
     } BufferPoolHead;
     
     enum OccState { NOT_OCCUPIED, WRITE_ON_SYNC, WRITE_ON_DIRTY, PERSISTENT_OCCUPIED };
@@ -120,8 +120,8 @@ private:
     typedef struct BufferHead {
 	OccState isOccupied;
 	char isDirty;
-	int numFixes;
-	int tabSetId;
+	unsigned numFixes;
+	unsigned tabSetId;
 	PageIdType pageId;
 	unsigned fixStat;
 	unsigned long long numUsage;
@@ -130,7 +130,6 @@ private:
     Chain _dbName;
     unsigned long long _numSegment;
     unsigned long long _numPages;
-    int _key;
     
     void **_pBufPool;
 
@@ -148,8 +147,8 @@ private:
 
     unsigned long long _poolStart;
     unsigned long long _statStart;
-    int _maxFixTries;
-    int _maxPageDelete;
+    unsigned _maxFixTries;
+    unsigned _maxPageDelete;
 
     ListT<PageIdType> _deletedPageList;
     
