@@ -29,12 +29,12 @@ public:
     
     enum CondType { AND, OR, PRED };
     
-    CegoCondition(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId);
+    CegoCondition(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     CegoCondition(CondType ct, CegoPredicate* pLeft, CegoPredicate* pRight);
     CegoCondition(CondType ct);
     ~CegoCondition();
 
-    void setTabSetId(int tabSetId);
+    void setTabSetId(unsigned tabSetId);
     
     void getPlanList(ListT<Element*>& planList);
 
@@ -48,15 +48,15 @@ public:
     CondType getCondType();
 
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId);
-    int getEncodingLength(CegoProcBlock *pBlock) const;
+    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     void clearAttrCache();
     
     ListT<CegoAttrDesc*> getAttrRefList() const;
     void getFieldList(ListT<CegoField>& fl, ListT<CegoField>** pFLA) const;
 
-    int evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
+    unsigned evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
     ListT<CegoAggregation*> getAggregationList();
 
     void setAggregationValue(ListT<CegoField>& jfl);
@@ -71,7 +71,7 @@ public:
 
     Chain getId(CegoProcBlock *pBlock) const;
 
-    Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const;
+    Chain toChain(unsigned defTabSetId, const Chain& indent = Chain("")) const;
     Chain dbFormat(CegoDatabaseFormater *pForm);
     
     CegoCondition* clone(bool isAttrRef = false);
