@@ -1293,12 +1293,12 @@ void CegoDatabaseManager::releaseLogFiles(const Chain& tableSet, bool waitForArc
         if ( *pStatus == Chain(XML_ACTIVE_VALUE) && File::exists(*pLog) ) 
         { 
             setLogFile(tabSetId, *pLog, true); 
-            unsigned long long minlsn = getMinLSN(tabSetId); 
-            if ( minlsn > 0 ) 
-            { 
-                log(_modId, Logger::NOTICE, Chain("Releasing logfile ") + *pLog + Chain(" LSN=") + Chain(minlsn)); 
-                setLogFileStatus(tableSet, *pLog, XML_OCCUPIED_VALUE); 
-            } 
+            // unsigned long long minlsn = getMinLSN(tabSetId); 
+            //if ( minlsn > 0 ) 
+            // { 
+	    log(_modId, Logger::NOTICE, Chain("Releasing logfile ") + *pLog); 
+	    setLogFileStatus(tableSet, *pLog, XML_OCCUPIED_VALUE); 
+            // } 
         } 
         pStatus = statusList.Next(); 
         pLog = lfList.Next(); 
