@@ -47,7 +47,7 @@ public:
     void distSetup(CegoAttrCond& attrCond, ListT<CegoField>** pFLA, CegoPredicate *pPred);
     
     // bool nextTuple(ListT<CegoField>& fl);
-    bool nextTuple(ListT<CegoField>** pFLA, int pos, int size);
+    bool nextTuple(ListT<CegoField>** pFLA, unsigned pos, unsigned size);
 
     void reset();
 
@@ -61,12 +61,12 @@ public:
     
     void sysSetup();
     void joinSetup(const CegoAttrCond& attrCond);
-    bool evalCondition(ListT<CegoField>** pFLA, int pos, int size);
-    bool evalCompare(CegoAttrComp* pAC, ListT<CegoField>** pFLA, int pos, int size);
-    bool getTuple(ListT<CegoField>** pFLA, int offset, int size);
+    bool evalCondition(ListT<CegoField>** pFLA, unsigned pos, unsigned size);
+    bool evalCompare(CegoAttrComp* pAC, ListT<CegoField>** pFLA, unsigned pos, unsigned size);
+    bool getTuple(ListT<CegoField>** pFLA, unsigned offset, unsigned size);
 
-    void nextRight(ListT<CegoField>** pFLA, int offset, int size);
-    void nextLeft(ListT<CegoField>** pFLA, int offset, int size);
+    void nextRight(ListT<CegoField>** pFLA, unsigned offset, unsigned size);
+    void nextLeft(ListT<CegoField>** pFLA, unsigned offset, unsigned size);
 
     void finishCaching();
     
@@ -76,7 +76,7 @@ public:
     Chain _tableName;
     Chain _tableAlias;
 
-    int _tabSetId;
+    unsigned _tabSetId;
 
     CegoSelect *_pSelect;
     CegoTableCursor* _pTC;
@@ -103,10 +103,10 @@ public:
     bool _isFirst;
 
     bool _useCache;
-    int _cacheRows;
-    int _cacheCols;
+    unsigned _cacheRows;
+    unsigned _cacheCols;
     
-    int _cachePos;
+    unsigned _cachePos;
     
     bool _evalPredicate;
     bool _isAttrCondValid;
@@ -127,7 +127,7 @@ public:
 
     ListT<Chain> _sysObjList;
 
-    int _cacheEntrySize;
+    unsigned _cacheEntrySize;
     ListT<CegoField> _cacheSchema;
     CegoFieldValue*** _pCacheArray;
     ListT< ListT<CegoFieldValue> >* _pCacheList;
