@@ -27,7 +27,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoExpr::CegoExpr(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId)
+CegoExpr::CegoExpr(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pTerm=0;
     _pExpr=0;
@@ -80,7 +80,7 @@ void CegoExpr::cleanUp()
 	_pTerm->cleanUp();
 }
 
-void CegoExpr::setTabSetId(int tabSetId)
+void CegoExpr::setTabSetId(unsigned tabSetId)
 {
     if ( _pExpr )
 	_pExpr->setTabSetId(tabSetId);
@@ -220,9 +220,9 @@ ListT<CegoAttrDesc*> CegoExpr::getAttrRefList() const
     return attrList;
 }
 
-int CegoExpr::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
+unsigned CegoExpr::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
 {
-    int refCount = 0;
+    unsigned refCount = 0;
 
     switch ( _expType )
     {
@@ -257,8 +257,8 @@ CegoField CegoExpr::evalField(const ListT<CegoField>& fl, bool graceful) const
 
 	// the type conversion refers to method : CegoFieldValue operator + ( const CegoFieldValue& fv1, const CegoFieldValue& fv2 )
 	CegoDataType dt;
-	int len;
-	int dim;
+	unsigned len;
+	unsigned dim;
 	
 	if ( f1.getType() == DECIMAL_TYPE )
 	{
@@ -292,8 +292,8 @@ CegoField CegoExpr::evalField(const ListT<CegoField>& fl, bool graceful) const
 	CegoField f2 =  _pTerm->evalField(fl, graceful);
 
 	CegoDataType dt;
-	int len;
-	int dim;
+	unsigned len;
+	unsigned dim;
 	
 	if ( f1.getType() == DECIMAL_TYPE )
 	{
@@ -449,7 +449,7 @@ Chain CegoExpr::getId(CegoProcBlock *pBlock) const
     return s;
 }
 
-Chain CegoExpr::toChain(int defTabSetId, const Chain& indent) const
+Chain CegoExpr::toChain(unsigned defTabSetId, const Chain& indent) const
 {
     Chain s;
     switch ( _expType )
@@ -503,7 +503,7 @@ void CegoExpr::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoExpr::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId)
+void CegoExpr::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pE = (char*)buf;
 
@@ -532,9 +532,9 @@ void CegoExpr::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, i
     }
 }
 
-int CegoExpr::getEncodingLength(CegoProcBlock *pBlock) const
+unsigned CegoExpr::getEncodingLength(CegoProcBlock *pBlock) const
 {
-    int len = 0;
+    unsigned len = 0;
     
     len += sizeof(CegoExpr::ExpType);
 
@@ -578,7 +578,6 @@ ostream& operator << (ostream& s, const CegoExpr& e)
 
 CegoExpr* CegoExpr::map(const Chain& viewAlias, const ListT<CegoExpr*>& exprList) const
 {
-
     CegoExpr* pMapExpr = 0;
     CegoTerm* pMapTerm = 0;
 
