@@ -37,11 +37,6 @@
 #include <string.h>
 #include <stdlib.h>
 
-// improved bsd random functions still not supported for mingw
-#ifdef HAVE_MINGW
-#define random rand
-#endif
-
 CegoFunction::CegoFunction(CegoFunction::FunctionType type)
 {
     _pTabMng = 0;
