@@ -30,7 +30,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoPredicate::CegoPredicate(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId)
+CegoPredicate::CegoPredicate(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pExpr1 = 0;
     _pExpr2 = 0;
@@ -233,7 +233,7 @@ CegoPredicate::~CegoPredicate()
     }
 }
 
-void CegoPredicate::setTabSetId(int tabSetId)
+void CegoPredicate::setTabSetId(unsigned tabSetId)
 {
     if ( _pExpr1 )
     {
@@ -706,9 +706,9 @@ void CegoPredicate::encode(char *buf, CegoProcBlock *pBlock)
 	_pExpr1->encode(pP, pBlock);
 	pP = pP + _pExpr1->getEncodingLength(pBlock);     
 
-	int num = _exprList.Size();
-	memcpy( pP, &num, sizeof(int));
-	pP = pP + sizeof(int);
+	unsigned num = _exprList.Size();
+	memcpy( pP, &num, sizeof(unsigned));
+	pP = pP + sizeof(unsigned);
       
 	CegoExpr** pExpr = _exprList.First();
 	while ( pExpr )
@@ -741,7 +741,7 @@ void CegoPredicate::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoPredicate::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId)
+void CegoPredicate::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pP = (char*)buf;
 
@@ -823,11 +823,11 @@ void CegoPredicate::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlo
 	_pExpr1 = new CegoExpr(pP, pGTM, pBlock, tabSetId);
 	pP = pP + _pExpr1->getEncodingLength(pBlock);
 
-	int num;
-	memcpy( &num, pP, sizeof(int));
-	pP = pP + sizeof(int);
+	unsigned num;
+	memcpy( &num, pP, sizeof(unsigned));
+	pP = pP + sizeof(unsigned);
 
-	for ( int i=0; i<num; i++ )
+	for ( unsigned i=0; i<num; i++ )
 	{
 	    CegoExpr *pExpr = new CegoExpr(pP, pGTM, pBlock, tabSetId);
 	    _exprList.Insert(pExpr);
@@ -854,9 +854,9 @@ void CegoPredicate::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlo
     }
 }
 
-int CegoPredicate::getEncodingLength(CegoProcBlock *pBlock) const
+unsigned CegoPredicate::getEncodingLength(CegoProcBlock *pBlock) const
 {
-    int len = 0;
+    unsigned len = 0;
     
     len += sizeof(CegoPredicate::CompMode);
     
@@ -919,7 +919,7 @@ int CegoPredicate::getEncodingLength(CegoProcBlock *pBlock) const
     case CegoPredicate::NOTIN:
     {
 	len += _pExpr1->getEncodingLength(pBlock);
-	len += sizeof(int);
+	len += sizeof(unsigned);
 
 	CegoExpr** pExpr = _exprList.First();
 	while ( pExpr )
@@ -1018,9 +1018,9 @@ ListT<CegoAttrDesc*> CegoPredicate::getAttrRefList() const
     return al; 
 }
 
-int CegoPredicate::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
+unsigned CegoPredicate::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
 {
-    int refCount = 0;
+    unsigned refCount = 0;
     
     switch (_mode )
     {
@@ -1204,9 +1204,9 @@ void CegoPredicate::getFieldList(ListT<CegoField>& fl, ListT<CegoField>** pFLA)
 }
     
 bool CegoPredicate::eval(ListT<CegoField>** pParentJoinBuf,
-			     int parentJoinBufPos,
+			     unsigned parentJoinBufPos,
 			     ListT<CegoField>** pJoinBuf,
-			     int pos,
+			     unsigned pos,
 			     CegoProcBlock *pBlock)
 {
     
@@ -1275,11 +1275,11 @@ bool CegoPredicate::eval(ListT<CegoField>** pParentJoinBuf,
 	    {
 		flArray = flStaticArray;
 		
-		int flpos=0;
+		unsigned flpos=0;
 
 		// first we take join buf with high priority ( first match on join buf )
 		
-		int i=pos;
+		unsigned i=pos;
 		while ( pJoinBuf[i] )
 		{
 		    if ( flpos > TABMNG_MAXJOINLEVEL )
@@ -1393,7 +1393,29 @@ bool CegoPredicate::eval(ListT<CegoField>** pParentJoinBuf,
 	    {		
 		_pSelect->reset();		
 		if ( flArray )
-		{		    
+		{
+		    /*
+		    cout << "Setting parent .." << endl;
+
+		    
+		    cout << "### flArray start ###" << endl;
+		    CegoField *pF = 0;	
+		    int flaPos=0;
+		    while ( flArray[flaPos] )
+		    {
+			CegoField *pF = flArray[flaPos]->First();
+			
+			while ( pF )
+			{
+			    cout << "Attr = " << pF->getTableAlias()  << "/" <<  pF->getTableName()
+				 << "/" << pF->getAttrName() << "="  << pF->getValue().valAsChain() << endl;
+			    pF = flArray[flaPos]->Next();
+			}
+			flaPos++;
+		    }
+		    cout << "### flArray end ###" << endl;
+		    */
+
 		    _pSelect->setParentJoinBuf(flArray);		    
 		}
 		_pSelect->setProcBlock(pBlock);
@@ -1401,6 +1423,8 @@ bool CegoPredicate::eval(ListT<CegoField>** pParentJoinBuf,
 		_pSelect->prepare();
 		
 		ListT<CegoField> fl;
+
+		// cout << "Select = " << _pSelect->toChain(0) << endl;
 		
 		if ( _pSelect->nextTuple(fl) )
 		{
@@ -2520,7 +2544,7 @@ Chain CegoPredicate::getId(CegoProcBlock *pBlock) const
     return s;
 }
 
-Chain CegoPredicate::toChain(int defTabSetId, const Chain& indent) const
+Chain CegoPredicate::toChain(unsigned defTabSetId, const Chain& indent) const
 {
     Chain s;
 
@@ -2563,7 +2587,7 @@ Chain CegoPredicate::toChain(int defTabSetId, const Chain& indent) const
 	}
 	
 	Chain addIndent;
-	for ( int i=1; i < (int)s.length(); i++ )
+	for ( unsigned i=1; i < (unsigned)s.length(); i++ )
 	    addIndent += Chain(" ");
 	
 	s +=  _pExpr2->toChain(defTabSetId, indent + addIndent);
@@ -2644,7 +2668,7 @@ Chain CegoPredicate::toChain(int defTabSetId, const Chain& indent) const
 	s += Chain(" in ( ");
 
 	Chain addIndent;
-	for ( int i=1; i < (int)s.length(); i++ )
+	for ( unsigned i=1; i < (unsigned)s.length(); i++ )
 	    addIndent += Chain(" ");
 
 	s += _pSelect->toChain(defTabSetId, indent + addIndent) + Chain(" )");   
@@ -2656,7 +2680,7 @@ Chain CegoPredicate::toChain(int defTabSetId, const Chain& indent) const
 	s += Chain(" not in ( ");
 
 	Chain addIndent;
-	for ( int i=1; i < (int)s.length(); i++ )
+	for ( unsigned i=1; i < (unsigned)s.length(); i++ )
 	    addIndent += Chain(" ");
 
 	s += _pSelect->toChain(defTabSetId, indent + addIndent) + Chain(" )");   
