@@ -113,7 +113,7 @@ void CegoProcAssignStmt::cleanUp()
     }
 }
 
-Chain CegoProcAssignStmt::toChain(int defTabSetId, const Chain& indent) const
+Chain CegoProcAssignStmt::toChain(unsigned defTabSetId, const Chain& indent) const
 {
     Chain s;
 	
@@ -128,7 +128,7 @@ Chain CegoProcAssignStmt::toChain(int defTabSetId, const Chain& indent) const
     {
 	Chain prefix = Chain(":")  + _paramName + Chain(" = ");
 	Chain addIndent;
-	for ( int i=0; i < (int)prefix.length(); i++ )
+	for ( unsigned i=0; i < (unsigned)prefix.length(); i++ )
 	    addIndent += Chain(" ");
 	s = indent + prefix + _pExpr->toChain(defTabSetId, indent + addIndent);
 	break;
