@@ -36,11 +36,11 @@ public:
 
     CegoProcObject();
     CegoProcObject(const CegoProcObject& ko);
-    CegoProcObject(const Chain& procName, int tabSetId = 0);
-    CegoProcObject(int tabSetId, const Chain& procName, const Chain& procText);
+    CegoProcObject(const Chain& procName, unsigned tabSetId = 0);
+    CegoProcObject(unsigned tabSetId, const Chain& procName, const Chain& procText);
     ~CegoProcObject();
     
-    int getEntrySize() const;
+    unsigned getEntrySize() const;
     void encode(char *buf) const;
     void decode(char *buf);
     const Chain& getProcText() const;
