@@ -53,7 +53,7 @@ public:
 
     enum SelectMode { SIMPLE, PLAIN, AGGREGATION, GROUPING };
 	
-    CegoSelect(char* buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, int tabSetId);
+    CegoSelect(char* buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     CegoSelect(ListT<CegoContentObject*>& coList,
 	       ListT<CegoExpr*>& exprList, 
 	       CegoPredicate* pPred,
@@ -62,7 +62,7 @@ public:
 	       ListT<CegoExpr*> *pOrderList,
 	       ListT<CegoOrderNode::Ordering>* pOrderOptList,
 	       bool isDistinct,
-	       int rowLimit,
+	       unsigned rowLimit,
 	       CegoDistManager* pGTM);
     ~CegoSelect();
 
@@ -80,28 +80,28 @@ public:
     void checkValidRef();
     void setParentJoinBuf(ListT<CegoField>** pParentJoinBuf = 0);
     void setProcBlock(CegoProcBlock *pBlock);
-    int evalExtTableReferences(CegoContentObject* pCO, const ListT<CegoField>& fl);
+    unsigned evalExtTableReferences(CegoContentObject* pCO, const ListT<CegoField>& fl);
     CegoPredicate* getPredicate();
     bool hasAliasReference() const;
     void getSchema(ListT<CegoField>& schema);
-    Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const;
+    Chain toChain(unsigned defTabSetId, const Chain& indent = Chain("")) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     ListT<CegoAttrDesc*> getAttrRefList() const;
     void getFieldList(ListT<CegoField>& fl, ListT<CegoField>** pFLA) const;
 
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, int tabSetId);
-    int getEncodingLength(CegoProcBlock *pBlock) const;
+    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     bool setViewCond(const Chain& viewAlias, CegoAttrCond& attrCond, CegoPredicate* pPred, ListT<CegoField> **pFLA);
-    void setTabSetId(int tabSetId);
-    int getExtRefCount() const;
+    void setTabSetId(unsigned tabSetId);
+    unsigned getExtRefCount() const;
     CegoSelect* clone( bool isAttrRef = false);
 
 private:
 
     void evalSchema(bool graceful);	
-    int evalTableReferences(CegoContentObject* pCO, const ListT<CegoField>& fl);
+    unsigned evalTableReferences(CegoContentObject* pCO, const ListT<CegoField>& fl);
     bool isPrepared() const;
     void analyzeJoin();
     bool nextAggTuple(ListT<CegoField>& jfl);
@@ -132,7 +132,7 @@ private:
     bool matchFieldValue(const CegoFieldValue& fv1, const CegoFieldValue& fv2, CegoComparison comp);    
     void setAggregationValue(CegoExpr *pExpr, ListT<CegoField>& jfl);
     void addObject4CO(CegoContentObject *pCO, SetT<CegoObject>& objList) const;
-    void setExtRefCount(int refCount);
+    void setExtRefCount(unsigned refCount);
     void mergeBuffer();
 
     void startCaching();
@@ -148,9 +148,9 @@ private:
     ListT<CegoContentObject*> _coList;
     ListT<CegoContentObject*> _joinList;
     ListT<CegoField> _joinFields;
-    int _joinLevel;
-    int _joinSize;
-    int _dcount;
+    unsigned _joinLevel;
+    unsigned _joinSize;
+    unsigned _dcount;
     ListT<CegoField>* _joinBuf[TABMNG_MAXJOINLEVEL];
     ListT<CegoField>**  _pParentJoinBuf;
 
@@ -165,9 +165,9 @@ private:
     CegoPredicate* _cursorPred[TABMNG_MAXJOINLEVEL];
     bool _firstTuple[TABMNG_MAXJOINLEVEL];
     CegoDatabaseManager *_pDBMng;
-    int _aggregationCount;
-    int _nextAid;
-    int _tabSetId;
+    unsigned _aggregationCount;
+    unsigned _nextAid;
+    unsigned _tabSetId;
     ListT<CegoAttrDesc*>* _pGroupList;
     CegoPredicate* _pHavingPred;
     ListT<CegoExpr*>* _pNativeOrderList;
@@ -189,7 +189,7 @@ private:
     ListT<CegoField> _cacheSchema;
     CegoFieldValue*** _pCacheArray;
     ListT< ListT<CegoFieldValue> >* _pCacheList;
-    int _cacheRows;
+    unsigned _cacheRows;
     unsigned long _cacheEntrySize;
     bool _isCached;
     Chain _viewCondId;
@@ -199,11 +199,11 @@ private:
     CegoGroupCursor *_pGroupCursor;
     CegoGroupSpace* _pGroupSpace;
     bool _isPrepared;
-    int _rowCount;
-    int _rowLimit;
+    unsigned _rowCount;
+    unsigned _rowLimit;
     bool _checkUnion;
     CegoSelect* _pUnionSelect;
-    int _extRefCount;
+    unsigned _extRefCount;
     NanoTimer _execTime;
  
     unsigned long _modId;
