@@ -8,7 +8,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2013 Bjoern Lemke
+// (C)opyright 2000-2025 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -20,13 +20,13 @@
 //
 ///////////////////////////////////////////////////////////////////////////////
 
-
-enum CegoTupleState { 
-    COMMITTED, 
-    INSERTED, 
-    DELETED, 
-    OBSOLETE };
-
+enum CegoTupleState
+{    
+    COMMITTED, // untouched, visible by all transactions
+    INSERTED,  // inserted by current transaction
+    DELETED, // deleted by current transaction
+    OBSOLETE // an already inserted tuple which has been deleted again
+};
 #endif
 
 
