@@ -142,20 +142,20 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 		    
 		    CegoDataType dt = CegoTypeConverter::getTypeId( colType );
 
-		    int colSize;
+		    unsigned colSize;
 		    
 		    if (dt == VARCHAR_TYPE
 			|| dt == BIGINT_TYPE
 			|| dt == DECIMAL_TYPE )
 		    {
-			colSize = (*pCol)->getAttributeValue(XML_COLSIZE_ATTR).asInteger();
+			colSize = (*pCol)->getAttributeValue(XML_COLSIZE_ATTR).asUnsigned();
 		    }
 		    else
 		    {
 			colSize = CegoTypeConverter::getTypeLen( dt );
 		    }
 
-		    int colDim;
+		    unsigned colDim;
 		    
 		    if ( dt == DECIMAL_TYPE )
 		    {
@@ -170,7 +170,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 			}
 			else
 			{
-			    colDim = dimCheck.asInteger();
+			    colDim = dimCheck.asUnsigned();
 			}
 		    }
 		    else
@@ -398,7 +398,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 	    
 	    Element **pViewSchemaElement = viewSchemaList.First();
 
-	    int colId=1;
+	    unsigned colId=1;
 	    ListT<CegoField> fl;
 	    if ( pViewSchemaElement )
 	    {
@@ -412,20 +412,20 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 		    
 		    CegoDataType dt = CegoTypeConverter::getTypeId( colType );
 
-		    int colSize;
+		    unsigned colSize;
 		    
 		    if (dt == VARCHAR_TYPE
 			|| dt == BIGINT_TYPE
 			|| dt == DECIMAL_TYPE )
 		    {
-			colSize = (*pCol)->getAttributeValue(XML_COLSIZE_ATTR).asInteger();
+			colSize = (*pCol)->getAttributeValue(XML_COLSIZE_ATTR).asUnsigned();
 		    }
 		    else
 		    {
 			colSize = CegoTypeConverter::getTypeLen( dt );
 		    }
 
-		    int colDim;
+		    unsigned colDim;
 		    if ( dt == DECIMAL_TYPE )
 		    {
 			
@@ -440,7 +440,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 			}
 			else
 			{
-			    colDim = dimCheck.asInteger();
+			    colDim = dimCheck.asUnsigned();
 			}
 		    }
 		    else
@@ -496,7 +496,7 @@ void CegoXPorter::xmlImportTableSet(const Chain& tableSet, bool isStructure, con
 		_pAH->sendInfo(info + Chain("\n"));
 	    _pDBMng->log(_modId, Logger::NOTICE, info);
 	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);	
+	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);	
 	    _pDBMng->addCounter(tabSetId, counterName, counterValue.asUnsignedLongLong(), true);
 	    
 	    pCounterElement = counterList.Next();
@@ -577,7 +577,7 @@ unsigned long long CegoXPorter::xmlImportTable(const Chain& tableSet, const Chai
 void CegoXPorter::xmlExportTableSet(const Chain& tableSet, bool isStructure, const Chain& expFile)
 {    
     _pDBMng->log(_modId, Logger::NOTICE, Chain("Exporting tableset ") +  tableSet);
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     XMLSuite xml;
 
@@ -1095,7 +1095,7 @@ unsigned long long CegoXPorter::xmlExportTable(const Chain& tableSet, const Chai
 {
     _pDBMng->log(_modId, Logger::NOTICE, Chain("Exporting table ") + tableName + Chain("..."));
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     XMLSuite xml;
 
@@ -1320,7 +1320,7 @@ void CegoXPorter::binExportTableSet(const Chain& tableSet, bool isStructure, con
 
     try
     {
-	int tabSetId = _pDBMng->getTabSetId(tableSet);
+	unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	
 	pOutFile->open(File::WRITE);
 
@@ -1563,7 +1563,7 @@ unsigned long long CegoXPorter::binExportTable(const Chain& tableSet, const Chai
 {
     _pDBMng->log(_modId, Logger::NOTICE, Chain("Exporting tableset ") + tableSet + Chain(" (binary) ..."));
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
    
     File *pOutFile = new File(expFile);
     
@@ -1605,14 +1605,14 @@ unsigned long long CegoXPorter::binExportTable(const Chain& tableSet, const Chai
 
 void CegoXPorter::writeHeader(File *pOutFile, const Chain& tableSet)
 {
-    int tslen = tableSet.length()-1;
+    unsigned tslen = tableSet.length()-1;
     _tag = TSTAG;
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
-    pOutFile->writeByte((char*)&tslen, sizeof(int));
+    pOutFile->writeByte((char*)&tslen, sizeof(unsigned));
     pOutFile->writeByte((char*)tableSet, tslen);    
 }
 
-unsigned long long CegoXPorter::writeTableObject(File *pOutFile, int tabSetId, const Chain& tableName, const ListT<CegoField>& schema, bool doPlain)
+unsigned long long CegoXPorter::writeTableObject(File *pOutFile, unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& schema, bool doPlain)
 {
     CegoField *pF;
     if ( doPlain )
@@ -1631,8 +1631,8 @@ unsigned long long CegoXPorter::writeTableObject(File *pOutFile, int tabSetId, c
     _tag = TABTAG;
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
         
-    int tlen = tableName.length()-1;
-    pOutFile->writeByte((char*)&tlen, sizeof(int));
+    unsigned tlen = tableName.length()-1;
+    pOutFile->writeByte((char*)&tlen, sizeof(unsigned));
     pOutFile->writeByte((char*)tableName, tlen);
     
     pF = schema.First();
@@ -1641,11 +1641,11 @@ unsigned long long CegoXPorter::writeTableObject(File *pOutFile, int tabSetId, c
 	_tag = FLDTAG;
 	pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
 
-	int id = pF->getId();
-	int alen = pF->getAttrName().length()-1;
+	unsigned id = pF->getId();
+	unsigned alen = pF->getAttrName().length()-1;
 
-	pOutFile->writeByte((char*)&id, sizeof(int));
-	pOutFile->writeByte((char*)&alen, sizeof(int));
+	pOutFile->writeByte((char*)&id, sizeof(unsigned));
+	pOutFile->writeByte((char*)&alen, sizeof(unsigned));
 	pOutFile->writeByte((char*)pF->getAttrName(), alen);
 
 	char isNullable;
@@ -1659,20 +1659,20 @@ unsigned long long CegoXPorter::writeTableObject(File *pOutFile, int tabSetId, c
 	CegoDataType dt = pF->getType();
 	pOutFile->writeByte((char*)&dt, sizeof(CegoDataType));		
 
-	int len = pF->getLength();
-	pOutFile->writeByte((char*)&len, sizeof(int));
+	unsigned len = pF->getLength();
+	pOutFile->writeByte((char*)&len, sizeof(unsigned));
 
-	int dim = pF->getDim();
-	pOutFile->writeByte((char*)&dim, sizeof(int));
+	unsigned dim = pF->getDim();
+	pOutFile->writeByte((char*)&dim, sizeof(unsigned));
 	
-	int defValLen = pF->getValue().getEncodingLength();
+	unsigned defValLen = pF->getValue().getEncodingLength();
 	    
 	if ( defValLen > XP_MAXCOLBUF )
 	    throw Exception(EXLOC, "Col buffer exceeded");
 	
 	pF->getValue().encode(_colBuffer);
 	    
-	pOutFile->writeByte((char*)&defValLen, sizeof(int));
+	pOutFile->writeByte((char*)&defValLen, sizeof(unsigned));
 	pOutFile->writeByte((char*)_colBuffer, defValLen);
 
 	pF = schema.Next();
@@ -1681,18 +1681,18 @@ unsigned long long CegoXPorter::writeTableObject(File *pOutFile, int tabSetId, c
     return writeTableData(pOutFile, tabSetId, tableName, schema, doPlain);
 }
 
-void CegoXPorter::writeIndexObject(File *pOutFile, int tabSetId, const Chain& idxName, const Chain& tableName, CegoObject::ObjectType type, const ListT<CegoField>& schema)
+void CegoXPorter::writeIndexObject(File *pOutFile, unsigned tabSetId, const Chain& idxName, const Chain& tableName, CegoObject::ObjectType type, const ListT<CegoField>& schema)
 {    
     _tag = IDXTAG;
 
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
         
-    int ilen = idxName.length()-1;
-    pOutFile->writeByte((char*)&ilen, sizeof(int));
+    unsigned ilen = idxName.length()-1;
+    pOutFile->writeByte((char*)&ilen, sizeof(unsigned));
     pOutFile->writeByte((char*)idxName, ilen);
 
-    int tlen = tableName.length()-1;
-    pOutFile->writeByte((char*)&tlen, sizeof(int));
+    unsigned tlen = tableName.length()-1;
+    pOutFile->writeByte((char*)&tlen, sizeof(unsigned));
     pOutFile->writeByte((char*)tableName, tlen);
 
     pOutFile->writeByte((char*)&type, sizeof(CegoObject::ObjectType));
@@ -1703,36 +1703,36 @@ void CegoXPorter::writeIndexObject(File *pOutFile, int tabSetId, const Chain& id
 	_tag = FLDTAG;
 	pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
 
-	int alen = pF->getAttrName().length()-1;
-	pOutFile->writeByte((char*)&alen, sizeof(int));
+	unsigned alen = pF->getAttrName().length()-1;
+	pOutFile->writeByte((char*)&alen, sizeof(unsigned));
 	pOutFile->writeByte((char*)pF->getAttrName(), alen);
 
 	CegoDataType dt = pF->getType();
 	pOutFile->writeByte((char*)&dt, sizeof(CegoDataType));		
 
-	int len = pF->getLength();
-	pOutFile->writeByte((char*)&len, sizeof(int));		
+	unsigned len = pF->getLength();
+	pOutFile->writeByte((char*)&len, sizeof(unsigned));		
 	
 	pF = schema.Next();
     }
 }
 
-void CegoXPorter::writeKeyObject(File *pOutFile, int tabSetId, const Chain& keyName, const Chain& tableName, const Chain& refTable, 
+void CegoXPorter::writeKeyObject(File *pOutFile, unsigned tabSetId, const Chain& keyName, const Chain& tableName, const Chain& refTable, 
 				 const ListT<CegoField>& keySchema, const ListT<CegoField>& refSchema)
 {
     _tag = KEYTAG;
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
     
-    int klen = keyName.length()-1;
-    pOutFile->writeByte((char*)&klen, sizeof(int));
+    unsigned klen = keyName.length()-1;
+    pOutFile->writeByte((char*)&klen, sizeof(unsigned));
     pOutFile->writeByte((char*)keyName, klen);
 
-    int tlen = tableName.length()-1;
-    pOutFile->writeByte((char*)&tlen, sizeof(int));
+    unsigned tlen = tableName.length()-1;
+    pOutFile->writeByte((char*)&tlen, sizeof(unsigned));
     pOutFile->writeByte((char*)tableName, tlen);
 
-    int rtlen = refTable.length()-1;
-    pOutFile->writeByte((char*)&rtlen, sizeof(int));
+    unsigned rtlen = refTable.length()-1;
+    pOutFile->writeByte((char*)&rtlen, sizeof(unsigned));
     pOutFile->writeByte((char*)refTable, rtlen);
     
     CegoField *pF = keySchema.First();
@@ -1741,8 +1741,8 @@ void CegoXPorter::writeKeyObject(File *pOutFile, int tabSetId, const Chain& keyN
 	_tag = FLDTAG;
 	pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
 	
-	int alen = pF->getAttrName().length()-1;
-	pOutFile->writeByte((char*)&alen, sizeof(int));
+	unsigned alen = pF->getAttrName().length()-1;
+	pOutFile->writeByte((char*)&alen, sizeof(unsigned));
 	pOutFile->writeByte((char*)pF->getAttrName(), alen);
 	
 	pF = keySchema.Next();
@@ -1757,31 +1757,31 @@ void CegoXPorter::writeKeyObject(File *pOutFile, int tabSetId, const Chain& keyN
 	_tag = FLDTAG;
 	pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
 	
-	int alen = pF->getAttrName().length()-1;
-	pOutFile->writeByte((char*)&alen, sizeof(int));
+	unsigned alen = pF->getAttrName().length()-1;
+	pOutFile->writeByte((char*)&alen, sizeof(unsigned));
 	pOutFile->writeByte((char*)pF->getAttrName(), alen);
 	
 	pF = refSchema.Next();	
     }
 }
 
-void CegoXPorter::writeCheckObject(File *pOutFile, int tabSetId, const Chain& checkName, const Chain& tableName, 
+void CegoXPorter::writeCheckObject(File *pOutFile, unsigned tabSetId, const Chain& checkName, const Chain& tableName, 
 				   CegoPredicate *pPredDesc)
 {
     _tag = CHECKTAG;
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
     
-    int cklen = checkName.length()-1;
-    pOutFile->writeByte((char*)&cklen, sizeof(int));
+    unsigned cklen = checkName.length()-1;
+    pOutFile->writeByte((char*)&cklen, sizeof(unsigned));
     pOutFile->writeByte((char*)checkName, cklen);
 
-    int tlen = tableName.length()-1;
-    pOutFile->writeByte((char*)&tlen, sizeof(int));
+    unsigned tlen = tableName.length()-1;
+    pOutFile->writeByte((char*)&tlen, sizeof(unsigned));
     pOutFile->writeByte((char*)tableName, tlen);
 
-    int pdlen = pPredDesc->getEncodingLength(0);
+    unsigned pdlen = pPredDesc->getEncodingLength(0);
 
-    pOutFile->writeByte((char*)&pdlen, sizeof(int));
+    pOutFile->writeByte((char*)&pdlen, sizeof(unsigned));
     
     if ( pdlen < XP_MAXPDBUF )
     {
@@ -1794,7 +1794,7 @@ void CegoXPorter::writeCheckObject(File *pOutFile, int tabSetId, const Chain& ch
     }
 }
 
-void CegoXPorter::writeTriggerObject(File *pOutFile, int tabSetId, const Chain& triggerName, const Chain& tableName,
+void CegoXPorter::writeTriggerObject(File *pOutFile, unsigned tabSetId, const Chain& triggerName, const Chain& tableName,
 				   bool isBefore, bool isOnInsert, bool isOnUpdate, bool isOnDelete, 
 				   const Chain& triggerText)
 {
@@ -1802,14 +1802,14 @@ void CegoXPorter::writeTriggerObject(File *pOutFile, int tabSetId, const Chain&
 
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
 
-    int len;
+    unsigned len;
     
     len = triggerName.length()-1;
-    pOutFile->writeByte((char*)&len, sizeof(int));
+    pOutFile->writeByte((char*)&len, sizeof(unsigned));
     pOutFile->writeByte((char*)triggerName, len);
 
     len = tableName.length()-1;
-    pOutFile->writeByte((char*)&len, sizeof(int));
+    pOutFile->writeByte((char*)&len, sizeof(unsigned));
     pOutFile->writeByte((char*)tableName, len);
 
     len = 1;
@@ -1840,25 +1840,25 @@ void CegoXPorter::writeTriggerObject(File *pOutFile, int tabSetId, const Chain&
     pOutFile->writeByte((char*)&flag, sizeof(char));
     
     len = triggerText.length()-1;
-    pOutFile->writeByte((char*)&len, sizeof(int));
+    pOutFile->writeByte((char*)&len, sizeof(unsigned));
     pOutFile->writeByte((char*)triggerText, len);
 }
 
-void CegoXPorter::writeAliasObject(File *pOutFile, int tabSetId, const Chain& aliasName, const Chain& tableName,
+void CegoXPorter::writeAliasObject(File *pOutFile, unsigned tabSetId, const Chain& aliasName, const Chain& tableName,
 				   const ListT<CegoAttrAlias>& aliasList)
 {
     _tag = ALIASTAG;
 
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
 
-    int len;
+    unsigned len;
     
     len = aliasName.length()-1;
-    pOutFile->writeByte((char*)&len, sizeof(int));
+    pOutFile->writeByte((char*)&len, sizeof(unsigned));
     pOutFile->writeByte((char*)aliasName, len);
 
     len = tableName.length()-1;
-    pOutFile->writeByte((char*)&len, sizeof(int));
+    pOutFile->writeByte((char*)&len, sizeof(unsigned));
     pOutFile->writeByte((char*)tableName, len);
 
     CegoAttrAlias *pA = aliasList.First();
@@ -1867,31 +1867,31 @@ void CegoXPorter::writeAliasObject(File *pOutFile, int tabSetId, const Chain& al
 	_tag = FLDTAG;
 	pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
 	
-	int len;
+	unsigned len;
 	
 	len = pA->getAttrName().length()-1;
-	pOutFile->writeByte((char*)&len, sizeof(int));
+	pOutFile->writeByte((char*)&len, sizeof(unsigned));
 	pOutFile->writeByte((char*)pA->getAttrName(), len);
 	
 	len = pA->getAliasName().length()-1;
-	pOutFile->writeByte((char*)&len, sizeof(int));
+	pOutFile->writeByte((char*)&len, sizeof(unsigned));
 	pOutFile->writeByte((char*)pA->getAliasName(), len);
 	
 	pA = aliasList.Next();
     }    
 }
 
-void CegoXPorter::writeViewObject(File *pOutFile, int tabSetId, const Chain& viewName, const ListT<CegoField>& viewSchema, const Chain& viewStmt)
+void CegoXPorter::writeViewObject(File *pOutFile, unsigned tabSetId, const Chain& viewName, const ListT<CegoField>& viewSchema, const Chain& viewStmt)
 {
     _tag = VIEWTAG;
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
         
-    int vlen = viewName.length()-1;
-    pOutFile->writeByte((char*)&vlen, sizeof(int));
+    unsigned vlen = viewName.length()-1;
+    pOutFile->writeByte((char*)&vlen, sizeof(unsigned));
     pOutFile->writeByte((char*)viewName, vlen);
 
-    int slen = viewStmt.length()-1;
-    pOutFile->writeByte((char*)&slen, sizeof(int));
+    unsigned slen = viewStmt.length()-1;
+    pOutFile->writeByte((char*)&slen, sizeof(unsigned));
     pOutFile->writeByte((char*)viewStmt, slen);
 
     CegoField *pF = viewSchema.First();
@@ -1900,49 +1900,49 @@ void CegoXPorter::writeViewObject(File *pOutFile, int tabSetId, const Chain& vie
 	_tag = FLDTAG;
 	pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
 	
-	int alen = pF->getAttrName().length()-1;
-	pOutFile->writeByte((char*)&alen, sizeof(int));
+	unsigned alen = pF->getAttrName().length()-1;
+	pOutFile->writeByte((char*)&alen, sizeof(unsigned));
 	pOutFile->writeByte((char*)pF->getAttrName(), alen);
 
 	CegoDataType dt = pF->getType();
 	pOutFile->writeByte((char*)&dt, sizeof(CegoDataType));		
 
-	int len = pF->getLength();
-	pOutFile->writeByte((char*)&len, sizeof(int));		
+	unsigned len = pF->getLength();
+	pOutFile->writeByte((char*)&len, sizeof(unsigned));		
 
-	int dim = pF->getDim();
-	pOutFile->writeByte((char*)&dim, sizeof(int));		
+	unsigned dim = pF->getDim();
+	pOutFile->writeByte((char*)&dim, sizeof(unsigned));		
 
 	pF = viewSchema.Next();
     }        
 }
 
-void CegoXPorter::writeProcObject(File *pOutFile, int tabSetId, const Chain& procName, const Chain& procText)
+void CegoXPorter::writeProcObject(File *pOutFile, unsigned tabSetId, const Chain& procName, const Chain& procText)
 {
     _tag = PROCTAG;
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
     
-    int plen = procName.length()-1;
-    pOutFile->writeByte((char*)&plen, sizeof(int));
+    unsigned plen = procName.length()-1;
+    pOutFile->writeByte((char*)&plen, sizeof(unsigned));
     pOutFile->writeByte((char*)procName, plen);
 
-    int txtlen = procText.length()-1;
-    pOutFile->writeByte((char*)&txtlen, sizeof(int));
+    unsigned txtlen = procText.length()-1;
+    pOutFile->writeByte((char*)&txtlen, sizeof(unsigned));
     pOutFile->writeByte((char*)procText, txtlen);
 }
 
-void CegoXPorter::writeCounterObject(File *pOutFile, int tabSetId, const Chain& counterName, unsigned long long counterValue)
+void CegoXPorter::writeCounterObject(File *pOutFile, unsigned tabSetId, const Chain& counterName, unsigned long long counterValue)
 {
     _tag = CNTTAG;
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
     
-    int clen = counterName.length()-1;
-    pOutFile->writeByte((char*)&clen, sizeof(int));
+    unsigned clen = counterName.length()-1;
+    pOutFile->writeByte((char*)&clen, sizeof(unsigned));
     pOutFile->writeByte((char*)counterName, clen);
     pOutFile->writeByte((char*)&counterValue, sizeof(unsigned long long));
 }
 
-unsigned long long CegoXPorter::writeTableData(File *pOutFile, int tabSetId, const Chain& tableName, const ListT<CegoField>& schema, bool doPlain)
+unsigned long long CegoXPorter::writeTableData(File *pOutFile, unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& schema, bool doPlain)
 {    
     if ( _pAH )
     {
@@ -1964,7 +1964,7 @@ unsigned long long CegoXPorter::writeTableData(File *pOutFile, int tabSetId, con
 	if  ( doPlain )
 	{
 	    char *buf;
-	    int len;
+	    unsigned len;
 	    
 	    buf = (char*)pOC->getFirst(len, dp);
 	    
@@ -1972,7 +1972,7 @@ unsigned long long CegoXPorter::writeTableData(File *pOutFile, int tabSetId, con
 	    {
 		_tag = ROWTAG;
 		pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
-		pOutFile->writeByte((char*)&len, sizeof(int));
+		pOutFile->writeByte((char*)&len, sizeof(unsigned));
 		pOutFile->writeByte(buf, len);
 		
 		rowCount++;
@@ -2016,7 +2016,7 @@ unsigned long long CegoXPorter::writeTableData(File *pOutFile, int tabSetId, con
     return rowCount;
 }
 
-void CegoXPorter::writeRow(File *pOutFile, int tabSetId, const ListT<CegoField>& rowSchema)
+void CegoXPorter::writeRow(File *pOutFile, unsigned tabSetId, const ListT<CegoField>& rowSchema)
 {    
     _tag = ROWTAG;
     pOutFile->writeByte((char*)&_tag, sizeof(BinTag));
@@ -2054,14 +2054,14 @@ void CegoXPorter::writeRow(File *pOutFile, int tabSetId, const ListT<CegoField>&
 	    }
 	    else
 	    {		
-		int colLen = pF->getValue().getEncodingLength();
+		unsigned colLen = pF->getValue().getEncodingLength();
 		
 		if ( colLen > XP_MAXCOLBUF )
 		    throw Exception(EXLOC, "Col buffer exceeded");
 		
 		pF->getValue().encode(_colBuffer);
 		
-		pOutFile->writeByte((char*)&colLen, sizeof(int));
+		pOutFile->writeByte((char*)&colLen, sizeof(unsigned));
 		pOutFile->writeByte((char*)_colBuffer, colLen);
 	    }
 	}		
@@ -2074,8 +2074,8 @@ void CegoXPorter::writeRow(File *pOutFile, int tabSetId, const ListT<CegoField>&
 	    }
 	    else
 	    {
-		int colLen = 0;
-		pOutFile->writeByte((char*)&colLen, sizeof(int));
+		unsigned colLen = 0;
+		pOutFile->writeByte((char*)&colLen, sizeof(unsigned));
 	    }
 	}
 	pF = rowSchema.Next();
@@ -2091,8 +2091,8 @@ void CegoXPorter::readHeader(File *pInFile, Chain& tableSet)
 	throw Exception(EXLOC, "Wrong format in import file");
     }
     
-    int tslen;
-    pInFile->readByte((char*)&tslen, sizeof(int));
+    unsigned tslen;
+    pInFile->readByte((char*)&tslen, sizeof(unsigned));
     
     if ( tslen > XP_MAXINBUF )
     {
@@ -2105,9 +2105,9 @@ void CegoXPorter::readHeader(File *pInFile, Chain& tableSet)
 
 unsigned long long CegoXPorter::readTableObject(File *pInFile, const Chain& tableSet, bool doPlain)
 {
-    int tlen;
+    unsigned tlen;
     
-    pInFile->readByte((char*)&tlen, sizeof(int));
+    pInFile->readByte((char*)&tlen, sizeof(unsigned));
     
     if ( tlen > XP_MAXINBUF )
     {
@@ -2128,11 +2128,11 @@ unsigned long long CegoXPorter::readTableObject(File *pInFile, const Chain& tabl
 
     while ( _tag == FLDTAG)
     {
-	int id;
-	pInFile->readByte((char*)&id, sizeof(int));
+	unsigned id;
+	pInFile->readByte((char*)&id, sizeof(unsigned));
 
-	int alen;
-	pInFile->readByte((char*)&alen, sizeof(int));
+	unsigned alen;
+	pInFile->readByte((char*)&alen, sizeof(unsigned));
 	if ( alen > XP_MAXINBUF )
 	{
 	    throw Exception(EXLOC, "InBuf exceeded");
@@ -2153,14 +2153,14 @@ unsigned long long CegoXPorter::readTableObject(File *pInFile, const Chain& tabl
 	CegoDataType dt;
 	pInFile->readByte((char*)&dt, sizeof(CegoDataType));		
 
-	int len;
-	pInFile->readByte((char*)&len, sizeof(int));		
+	unsigned len;
+	pInFile->readByte((char*)&len, sizeof(unsigned));		
 
-	int dim;
-	pInFile->readByte((char*)&dim, sizeof(int));		
+	unsigned dim;
+	pInFile->readByte((char*)&dim, sizeof(unsigned));		
 
-	int defValLen;
-	pInFile->readByte((char*)&defValLen, sizeof(int));
+	unsigned defValLen;
+	pInFile->readByte((char*)&defValLen, sizeof(unsigned));
 	
 	CegoFieldValue defValue;
 	if ( defValLen > 0 )
@@ -2190,7 +2190,7 @@ unsigned long long CegoXPorter::readTableObject(File *pInFile, const Chain& tabl
 
     if ( doPlain )
     {
-	int tabSetId = _pDBMng->getTabSetId(tableSet);
+	unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	
 	CegoBufferPage bp;
 	_pGTM->getObjectWithFix(tabSetId, tableName, CegoObject::TABLE, _oe, bp);
@@ -2199,8 +2199,8 @@ unsigned long long CegoXPorter::readTableObject(File *pInFile, const Chain& tabl
 	char rowBuf[XP_MAXROWBUF];
 	while ( _tag == ROWTAG )
 	{	    
-	    int rowLen;
-	    pInFile->readByte((char*)&rowLen, sizeof(int));
+	    unsigned rowLen;
+	    pInFile->readByte((char*)&rowLen, sizeof(unsigned));
 
 	    if ( rowLen > XP_MAXROWBUF )
 		throw Exception(EXLOC, "Import row buffer exceeded");
@@ -2228,13 +2228,13 @@ unsigned long long CegoXPorter::readTableObject(File *pInFile, const Chain& tabl
 	ListT<CegoTriggerObject> triggerList;
 	ListT<CegoAliasObject> aliasList;
 
-	int tabSetId = _pDBMng->getTabSetId(tableSet);
+	unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	
 	CegoBufferPage bp;
 	_pGTM->getObjectWithFix(tabSetId, tableName, CegoObject::TABLE, _oe, bp);
 	_sysEntry = CegoDataPointer(bp.getPageId(), bp.getEntryPos());
 	
-	int numInvalid;
+	unsigned numInvalid;
 	_pGTM->getObjectListByTable(_oe.getTabSetId(), _oe.getName(), idxList, btreeList, keyList, checkList, triggerList, aliasList,
 				    numInvalid);
 	
@@ -2261,9 +2261,9 @@ unsigned long long CegoXPorter::readTableObject(File *pInFile, const Chain& tabl
 
 void CegoXPorter::readIndexObject(File *pInFile, const Chain& tableSet)
 {
-    int ilen;
+    unsigned ilen;
    
-    pInFile->readByte((char*)&ilen, sizeof(int));
+    pInFile->readByte((char*)&ilen, sizeof(unsigned));
     
     if ( ilen > XP_MAXINBUF )
     {
@@ -2273,8 +2273,8 @@ void CegoXPorter::readIndexObject(File *pInFile, const Chain& tableSet)
     pInFile->readByte((char*)_inBuf, ilen);
     Chain idxName = Chain(_inBuf, ilen);
     
-    int tlen;    
-    pInFile->readByte((char*)&tlen, sizeof(int));
+    unsigned tlen;    
+    pInFile->readByte((char*)&tlen, sizeof(unsigned));
     
     if ( tlen > XP_MAXINBUF )
     {
@@ -2293,8 +2293,8 @@ void CegoXPorter::readIndexObject(File *pInFile, const Chain& tableSet)
 	
     while ( _tag == FLDTAG)
     {
-	int alen;
-	pInFile->readByte((char*)&alen, sizeof(int));
+	unsigned alen;
+	pInFile->readByte((char*)&alen, sizeof(unsigned));
 	if ( alen > XP_MAXINBUF )
 	{
 	    throw Exception(EXLOC, "Import buffer exceeded");
@@ -2306,8 +2306,8 @@ void CegoXPorter::readIndexObject(File *pInFile, const Chain& tableSet)
 	CegoDataType dt;
 	pInFile->readByte((char*)&dt, sizeof(CegoDataType));		
 
-	int len;
-	pInFile->readByte((char*)&len, sizeof(int));		
+	unsigned len;
+	pInFile->readByte((char*)&len, sizeof(unsigned));		
 	
 	schema.Insert(CegoField(tableName, tableName, attrName, dt, len));
 
@@ -2324,8 +2324,8 @@ void CegoXPorter::readIndexObject(File *pInFile, const Chain& tableSet)
 
 void CegoXPorter::readKeyObject(File *pInFile, const Chain& tableSet)
 {
-    int klen;    
-    pInFile->readByte((char*)&klen, sizeof(int));
+    unsigned klen;    
+    pInFile->readByte((char*)&klen, sizeof(unsigned));
     if ( klen > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2333,8 +2333,8 @@ void CegoXPorter::readKeyObject(File *pInFile, const Chain& tableSet)
     pInFile->readByte((char*)_inBuf, klen);
     Chain keyName = Chain(_inBuf, klen);
 
-    int tlen;    
-    pInFile->readByte((char*)&tlen, sizeof(int));
+    unsigned tlen;    
+    pInFile->readByte((char*)&tlen, sizeof(unsigned));
     if ( tlen > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2342,8 +2342,8 @@ void CegoXPorter::readKeyObject(File *pInFile, const Chain& tableSet)
     pInFile->readByte((char*)_inBuf, tlen);
     Chain tableName = Chain(_inBuf, tlen);
 
-    int rtlen;    
-    pInFile->readByte((char*)&rtlen, sizeof(int));
+    unsigned rtlen;    
+    pInFile->readByte((char*)&rtlen, sizeof(unsigned));
     if ( rtlen > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2355,8 +2355,8 @@ void CegoXPorter::readKeyObject(File *pInFile, const Chain& tableSet)
     ListT<CegoField> keySchema;	
     while ( _tag == FLDTAG)
     {
-	int alen;
-	pInFile->readByte((char*)&alen, sizeof(int));
+	unsigned alen;
+	pInFile->readByte((char*)&alen, sizeof(unsigned));
 	if ( alen > XP_MAXINBUF )
 	{
 	    throw Exception(EXLOC, "Import buffer exceeded");
@@ -2377,8 +2377,8 @@ void CegoXPorter::readKeyObject(File *pInFile, const Chain& tableSet)
     ListT<CegoField> refSchema;	
     while ( _tag == FLDTAG)
     {
-	int alen;
-	pInFile->readByte((char*)&alen, sizeof(int));
+	unsigned alen;
+	pInFile->readByte((char*)&alen, sizeof(unsigned));
 	if ( alen > XP_MAXINBUF )
 	{
 	    throw Exception(EXLOC, "Import buffer exceeded");
@@ -2402,8 +2402,8 @@ void CegoXPorter::readKeyObject(File *pInFile, const Chain& tableSet)
 
 void CegoXPorter::readCheckObject(File *pInFile, const Chain& tableSet)
 {
-    int cklen;    
-    pInFile->readByte((char*)&cklen, sizeof(int));
+    unsigned cklen;    
+    pInFile->readByte((char*)&cklen, sizeof(unsigned));
     if ( cklen > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2411,8 +2411,8 @@ void CegoXPorter::readCheckObject(File *pInFile, const Chain& tableSet)
     pInFile->readByte((char*)_inBuf, cklen);
     Chain checkName = Chain(_inBuf, cklen);
 
-    int tlen;    
-    pInFile->readByte((char*)&tlen, sizeof(int));
+    unsigned tlen;    
+    pInFile->readByte((char*)&tlen, sizeof(unsigned));
     if ( tlen > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2420,15 +2420,15 @@ void CegoXPorter::readCheckObject(File *pInFile, const Chain& tableSet)
     pInFile->readByte((char*)_inBuf, tlen);
     Chain tableName = Chain(_inBuf, tlen);
 
-    int pdlen;    
-    pInFile->readByte((char*)&pdlen, sizeof(int));
+    unsigned pdlen;    
+    pInFile->readByte((char*)&pdlen, sizeof(unsigned));
     if ( pdlen > XP_MAXPDBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
     }
     pInFile->readByte((char*)_pdBuffer, pdlen);
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);    
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
     CegoPredicate *pPredDesc = new CegoPredicate(_pdBuffer, _pGTM, 0, tabSetId);
 
     pInFile->readByte((char*)&_tag, sizeof(BinTag));
@@ -2443,9 +2443,9 @@ void CegoXPorter::readCheckObject(File *pInFile, const Chain& tableSet)
 
 void CegoXPorter::readTriggerObject(File *pInFile, const Chain& tableSet)
 {
-    int len;
+    unsigned len;
 
-    pInFile->readByte((char*)&len, sizeof(int));
+    pInFile->readByte((char*)&len, sizeof(unsigned));
     if ( len > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2454,7 +2454,7 @@ void CegoXPorter::readTriggerObject(File *pInFile, const Chain& tableSet)
     pInFile->readByte((char*)_inBuf, len);
     Chain triggerName = Chain(_inBuf, len);
 
-    pInFile->readByte((char*)&len, sizeof(int));
+    pInFile->readByte((char*)&len, sizeof(unsigned));
     if ( len > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2494,7 +2494,7 @@ void CegoXPorter::readTriggerObject(File *pInFile, const Chain& tableSet)
 	isOnDelete = false;
 
 
-    pInFile->readByte((char*)&len, sizeof(int));
+    pInFile->readByte((char*)&len, sizeof(unsigned));
     if ( len > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2517,8 +2517,8 @@ void CegoXPorter::readTriggerObject(File *pInFile, const Chain& tableSet)
 
 void CegoXPorter::readAliasObject(File *pInFile, const Chain& tableSet)
 {
-    int len;    
-    pInFile->readByte((char*)&len, sizeof(int));
+    unsigned len;    
+    pInFile->readByte((char*)&len, sizeof(unsigned));
     if ( len > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2527,7 +2527,7 @@ void CegoXPorter::readAliasObject(File *pInFile, const Chain& tableSet)
     pInFile->readByte((char*)_inBuf, len);
     Chain aliasName = Chain(_inBuf, len);
 
-    pInFile->readByte((char*)&len, sizeof(int));
+    pInFile->readByte((char*)&len, sizeof(unsigned));
     if ( len > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "InBuf exceeded");
@@ -2540,7 +2540,7 @@ void CegoXPorter::readAliasObject(File *pInFile, const Chain& tableSet)
     ListT<CegoAttrAlias> aliasList;
     while ( _tag == FLDTAG)
     {
-	pInFile->readByte((char*)&len, sizeof(int));
+	pInFile->readByte((char*)&len, sizeof(unsigned));
 	if ( len > XP_MAXINBUF )
 	{
 	    throw Exception(EXLOC, "InBuf exceeded");
@@ -2549,7 +2549,7 @@ void CegoXPorter::readAliasObject(File *pInFile, const Chain& tableSet)
 	pInFile->readByte((char*)_inBuf, len);
 	Chain attrName = Chain(_inBuf, len);
 
-	pInFile->readByte((char*)&len, sizeof(int));
+	pInFile->readByte((char*)&len, sizeof(unsigned));
 	if ( len > XP_MAXINBUF )
 	{
 	    throw Exception(EXLOC, "InBuf exceeded");
@@ -2574,8 +2574,8 @@ void CegoXPorter::readAliasObject(File *pInFile, const Chain& tableSet)
 
 void CegoXPorter::readViewObject(File *pInFile, const Chain& tableSet)
 {
-    int vlen;    
-    pInFile->readByte((char*)&vlen, sizeof(int));
+    unsigned vlen;    
+    pInFile->readByte((char*)&vlen, sizeof(unsigned));
     if ( vlen > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2584,8 +2584,8 @@ void CegoXPorter::readViewObject(File *pInFile, const Chain& tableSet)
     pInFile->readByte((char*)_inBuf, vlen);
     Chain viewName = Chain(_inBuf, vlen);
 
-    int slen;    
-    pInFile->readByte((char*)&slen, sizeof(int));
+    unsigned slen;    
+    pInFile->readByte((char*)&slen, sizeof(unsigned));
     if ( slen > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "InBuf exceeded");
@@ -2596,11 +2596,11 @@ void CegoXPorter::readViewObject(File *pInFile, const Chain& tableSet)
     pInFile->readByte((char*)&_tag, sizeof(BinTag));
 
     ListT<CegoField> viewSchema;
-    int colId=1;
+    unsigned colId=1;
     while ( _tag == FLDTAG)
     {
-	int alen;
-	pInFile->readByte((char*)&alen, sizeof(int));
+	unsigned alen;
+	pInFile->readByte((char*)&alen, sizeof(unsigned));
 	if ( alen > XP_MAXINBUF )
 	{
 	    throw Exception(EXLOC, "InBuf exceeded");
@@ -2612,11 +2612,11 @@ void CegoXPorter::readViewObject(File *pInFile, const Chain& tableSet)
 	CegoDataType dt;
 	pInFile->readByte((char*)&dt, sizeof(CegoDataType));		
 	
-	int len;
-	pInFile->readByte((char*)&len, sizeof(int));
+	unsigned len;
+	pInFile->readByte((char*)&len, sizeof(unsigned));
 
-	int dim;
-	pInFile->readByte((char*)&dim, sizeof(int));
+	unsigned dim;
+	pInFile->readByte((char*)&dim, sizeof(unsigned));
 
 
 	CegoField f(CegoField(viewName, viewName, attrName, dt, len, dim));
@@ -2638,8 +2638,8 @@ void CegoXPorter::readViewObject(File *pInFile, const Chain& tableSet)
 
 void CegoXPorter::readProcObject(File *pInFile, const Chain& tableSet)
 {
-    int plen;    
-    pInFile->readByte((char*)&plen, sizeof(int));
+    unsigned plen;    
+    pInFile->readByte((char*)&plen, sizeof(unsigned));
     if ( plen > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2647,8 +2647,8 @@ void CegoXPorter::readProcObject(File *pInFile, const Chain& tableSet)
     pInFile->readByte((char*)_inBuf, plen);
     Chain procName = Chain(_inBuf, plen);
 
-    int txtlen;    
-    pInFile->readByte((char*)&txtlen, sizeof(int));
+    unsigned txtlen;    
+    pInFile->readByte((char*)&txtlen, sizeof(unsigned));
     if ( txtlen > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2668,8 +2668,8 @@ void CegoXPorter::readProcObject(File *pInFile, const Chain& tableSet)
 
 void CegoXPorter::readCounterObject(File *pInFile, const Chain& tableSet)
 {
-    int clen;
-    pInFile->readByte((char*)&clen, sizeof(int));
+    unsigned clen;
+    pInFile->readByte((char*)&clen, sizeof(unsigned));
     if ( clen > XP_MAXINBUF )
     {
 	throw Exception(EXLOC, "Import buffer exceeded");
@@ -2685,13 +2685,13 @@ void CegoXPorter::readCounterObject(File *pInFile, const Chain& tableSet)
 	_pAH->sendInfo(info + Chain("\n"));
     _pDBMng->log(_modId, Logger::NOTICE, info);
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);	
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);	
     _pDBMng->addCounter(tabSetId, counterName, counterValue, true);
 
     pInFile->readByte((char*)&_tag, sizeof(BinTag));
 }
 
-void CegoXPorter::readRow(File *pInFile, int tabSetId, const Chain& tableName, const ListT<CegoField>& rowSchema)
+void CegoXPorter::readRow(File *pInFile, unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& rowSchema)
 {
     ListT<CegoField> fvl;
 
@@ -2766,8 +2766,8 @@ void CegoXPorter::readRow(File *pInFile, int tabSetId, const Chain& tableName, c
 	}
 	else
 	{
-	    int colLen;
-	    pInFile->readByte((char*)&colLen, sizeof(int));
+	    unsigned colLen;
+	    pInFile->readByte((char*)&colLen, sizeof(unsigned));
 	    
 	    CegoFieldValue fv;
 	    if ( colLen > 0 )
